@@ -687,6 +687,8 @@ css_parser_parse_simple_selector (const gchar *buffer, gint start_pos, gint end_
 
 	result = g_new (CssSimpleSelector, 1);
 	tail = g_new (CssTail, n_tail_max);
+	tail->type = -1;
+	tail->t.attr_sel.val.type = -1;
 	
 	if (c == '*') {
 		result->is_star = TRUE;
